@@ -1,6 +1,6 @@
 from typing import Callable, Any
 
-from probability.discrete.joint import Joint
+from probability.discrete._old.joint import Joint
 
 
 class Hypotheses(object):
