@@ -68,10 +68,10 @@ class BetaBinomialConjugate(
         :param beta: Value for the β hyper-parameter of the prior Beta
                       distribution.
         """
-        self._alpha: float = alpha
-        self._beta: float = beta
         self._n: int = n
         self._k: int = k
+        self._alpha: float = alpha
+        self._beta: float = beta
 
     # region posterior hyper-parameters
 
@@ -86,6 +86,10 @@ class BetaBinomialConjugate(
     # endregion
 
     def prior(self) -> Beta:
+        """
+        Return a Beta distribution reflecting the prior belief about the
+        distribution of the parameter p, before seeing any data.
+        """
         return Beta(
             alpha=self._alpha, beta=self._beta
         ).with_y_label(
@@ -93,12 +97,21 @@ class BetaBinomialConjugate(
         ).prepend_to_label('Prior: ')
 
     def likelihood(self) -> Binomial:
+        """
+        Return a distribution reflecting the likelihood of observing
+        the data, under a Binomial model, independent of the prior belief about
+        the distribution of parameter p.
+        """
         return Binomial(
             n=self._n,
             p=self._k / self._n
         )
 
     def posterior(self) -> Beta:
+        """
+        Return a Beta distribution reflecting the posterior belief about the
+        distribution of the parameter p, after observing the data.
+        """
         return Beta(
             alpha=self.alpha_prime,
             beta=self.beta_prime
@@ -295,7 +308,7 @@ class BetaBinomialConjugate(
     def __str__(self):
 
         return (
-            f'BetaBinomial('
+            f'BetaBinomialConjugate('
             f'α={num_format(self._alpha, 3)}, '
             f'β={num_format(self._beta, 3)}, '
             f'n={self._n}, k={self._k})'
@@ -304,7 +317,7 @@ class BetaBinomialConjugate(
     def __repr__(self):
 
         return (
-            f'BetaBinomial('
+            f'BetaBinomialConjugate('
             f'alpha={self._alpha}, '
             f'beta={self._beta}, '
             f'n={self._n}, '
