@@ -62,10 +62,10 @@ class BetaGeometricConjugate(
                      distribution. Number of prior failures
                      ( = total trials - successful trials).
         """
-        self._alpha: float = alpha
-        self._beta: float = beta
         self._n: int = n
         self._k: int = k
+        self._alpha: float = alpha
+        self._beta: float = beta
 
     # region posterior hyper-parameters
 
@@ -80,6 +80,10 @@ class BetaGeometricConjugate(
     # endregion
 
     def prior(self) -> Beta:
+        """
+        Return a Beta distribution reflecting the prior belief about the
+        distribution of the parameter p, before seeing any data.
+        """
         return Beta(
             alpha=self._alpha, beta=self._beta
         ).with_y_label(
@@ -89,9 +93,18 @@ class BetaGeometricConjugate(
         ).prepend_to_label('Prior: ')
 
     def likelihood(self) -> Geometric:
+        """
+        Return a distribution reflecting the likelihood of observing
+        the data, under a Geometric model, independent of the prior belief about
+        the distribution of parameter p.
+        """
         return Geometric(p=self._n / self._k)
 
     def posterior(self) -> Beta:
+        """
+        Return a Beta distribution reflecting the posterior belief about the
+        distribution of the parameter p, after observing the data.
+        """
         return Beta(
             alpha=self.alpha_prime,
             beta=self.beta_prime
@@ -247,7 +260,7 @@ class BetaGeometricConjugate(
 
     def __str__(self):
 
-        return f'BetaGeometric(' \
+        return f'BetaGeometricConjugate(' \
                f'α={num_format(self._alpha, 3)}, ' \
                f'β={num_format(self._beta, 3)}, ' \
                f'n={self._n}, ' \
@@ -256,7 +269,7 @@ class BetaGeometricConjugate(
 
     def __repr__(self):
 
-        return f'BetaGeometric(' \
+        return f'BetaGeometricConjugate(' \
                f'alpha={self._alpha}, ' \
                f'beta={self._beta}, ' \
                f'n={self._n}, ' \
