@@ -3,7 +3,9 @@ from scipy.stats import rv_continuous, gamma
 from probability.distributions.mixins.attributes import AlphaFloatDMixin, \
     BetaFloatDMixin
 from probability.distributions.mixins.calculable_mixins import CalculableMixin
-from probability.distributions.mixins.rv_continuous_1d_mixin import RVContinuous1dMixin
+from probability.distributions.mixins.rv_continuous_1d_mixin import \
+    RVContinuous1dMixin
+from probability.utils import num_format
 
 
 class Gamma(
@@ -76,9 +78,17 @@ class Gamma(
     def __str__(self):
 
         if self._parameterization == 'αβ':
-            return f'Gamma(α={self._alpha}, β={self._beta})'
+            return (
+                f'Gamma('
+                f'α={num_format(self._alpha, 3)}, '
+                f'β={num_format(self._beta, 3)})'
+            )
         elif self._parameterization == 'kθ':
-            return f'Gamma(k={self._alpha}, θ={1 / self._beta})'
+            return (
+                f'Gamma('
+                f'k={num_format(self._alpha, 3)}, '
+                f'θ={num_format(1 / self._beta, 3)})'
+            )
 
     def __repr__(self):
 
