@@ -1,6 +1,8 @@
 from typing import Iterable, overload, Optional
 
 from matplotlib.axes import Axes
+from numpy import linspace
+
 from mpl_format.axes import AxesFormatter
 from pandas import Series
 from scipy.stats import rv_continuous
@@ -11,6 +13,9 @@ from probability.distributions.mixins.plottable_mixin import \
 
 class ContinuousFunction1d(object):
 
+    lower_bound: Optional[float]
+    upper_bound: Optional[float]
+
     def __init__(self,
                  distribution: rv_continuous,
                  method_name: str,
@@ -31,7 +36,7 @@ class ContinuousFunction1d(object):
     def at(self, x: Iterable) -> Series:
         pass
 
-    def at(self, x):
+    def at(self, x: Optional[Iterable]):
         """
         Log of the probability density function of the given RV.
         """
@@ -39,9 +44,18 @@ class ContinuousFunction1d(object):
             return self._method(x)
         elif isinstance(x, Iterable):
             return Series(index=x, data=self._method(x), name=self._name)
+        elif x is None:
+            if (
+                    getattr(self, 'lower_bound') is not None and
+                    getattr(self, 'upper_bound') is not None
+            ):
+                x = linspace(self.lower_bound, self.upper_bound, 1001)
+                return self.at(x)
+        else:
+            raise ValueError('Must pass x if distribution has no bounds.')
 
     def plot(self,
-             x: Iterable,
+             x: Optional[Iterable],
              kind: str = 'line',
              color: str = 'C0',
              mean: bool = False,
