@@ -1,6 +1,6 @@
 from matplotlib.axes import Axes
 from scipy.stats import rv_continuous
-from typing import Iterable
+from typing import Iterable, Optional, Union
 
 from probability.distributions.mixins.plottable_mixin import \
     ContinuousPlottableMixin
@@ -21,7 +21,10 @@ class RVContinuous1dMixin(
     _distribution: rv_continuous
     _num_samples: int = 1000000
 
-    def plot(self, x: Iterable, kind: str = 'line', color: str = 'C0',
+    def plot(self,
+             x: Optional[Iterable] = None,
+             kind: str = 'line',
+             color: str = 'C0',
              ax: Axes = None, **kwargs) -> Axes:
         """
         Plot the PDF of the distribution.
@@ -33,3 +36,29 @@ class RVContinuous1dMixin(
         :param kwargs: Additional arguments for the matplotlib plot function.
         """
         return self.pdf().plot(x=x, kind=kind, color=color, ax=ax, **kwargs)
+
+    def __le__(self, other: Union['RVS1dMixin', int, float]) -> float:
+
+        if type(other) in (int, float):
+            return self.cdf().at(other)
+        elif isinstance(other, RVS1dMixin):
+            return super(self).__le__(other)
+        else:
+            raise TypeError('other must be of type int, float or Rvs1dMixin')
+
+    def __lt__(self, other: Union['RVS1dMixin', int, float]) -> float:
+
+        return self.__le__(other)
+
+    def __ge__(self, other: Union['RVS1dMixin', int, float]) -> float:
+
+        if type(other) in (int, float):
+            return 1 - self.__le__(other)
+        elif isinstance(other, RVS1dMixin):
+            return super(self).__ge__(other)
+        else:
+            raise TypeError('other must be of type int, float or Rvs1dMixin')
+
+    def __gt__(self, other: Union['RVS1dMixin', int, float]) -> float:
+
+        return self.__ge__(other)
